@@ -405,10 +405,10 @@ void integrator::start() {
   reinit();
   init_lat(); // must be done here !
   // add buttons unique to primer window
-  new instance_button <integrator> (*mb,"reinit",&reinit, this);
+  new instance_button <integrator> (*mb,"reinit",&integrator::reinit, this);
   new instance_button <integrator> (*mb,">",&integrator::step_handler,this);
   new switch_button(*mb,">>","||",&step_mode, (VVP) &player_pmset, this);
-  new instance_button <play_main> (*mb,"spawn",&spawn,this);
+  new instance_button <play_main> (*mb,"spawn",&integrator::spawn,this);
   new quit_button(*mb);
     
   main_loop();
