@@ -4,6 +4,7 @@
 // in a set of source files, displays inheritance graph with buttons
 // upon BPress the source pops up 
 
+
 #include "tree.h" // includes window.h
 #include "files.h"
 
@@ -13,7 +14,15 @@
 #include <ctype.h>
 #include <sys/stat.h>
 #include <dirent.h>
-#include "regex.h"
+
+// files rx.h, rx.c are from librx, and were part of libg++
+#ifdef NEED_RX
+extern "C" {
+#include "rx.h"
+}
+#else 
+#include <regex.h>
+#endif
 
 #if 0
 #define Dprintf(format, args...) printf(format, ## args)
@@ -112,7 +121,7 @@ public:
     rpb.fastmap = (char *) malloc(256);
     re_compile_pattern(exp,strlen(exp),&rpb);
   }
-  Search(char *string, int size) { 
+  int Search(char *string, int size) { 
     int pos = re_search(&rpb,string,size,0,size,0);
     if (pos < 0) return -1;
     int match = re_match(&rpb,string,size,pos,0);
