@@ -120,7 +120,7 @@ void rec_dir(char *path, DirTree* parent) {
 
 // if commandline arg given use it as search path, else use ".."
 int main(int argc, char* argv[]) {
-  char *path = (argc > 1) ? argv[1] : "..";
+  char *path = (argc > 1) ? argv[1] : (char*) "..";
   DirTree *top = new DirTree(path,path);
   rec_dir(path,top);
   Dir_main *mw = new Dir_main(argv[0],400,450);
