@@ -14,7 +14,7 @@ public: myedit(window &parent, int w,int h, int x, int y) :
   } 
 };
 
-main(int /*argc*/, char *argv[]) { 
+int main(int /*argc*/, char *argv[]) { 
   main_window *mw = new main_window(argv[0],200,100);
   new edit_window(*mw,"1234",180,20,10,10);  
   new myedit(*mw,180,20,10,40);
