@@ -38,7 +38,7 @@ void open_new_file(text_viewer *ts, char *fina, char *buf) {
 
 int top = 0;
 
-void spawn(char *last_fina) { // creates a new window with the last file
+void spawn(const char *last_fina) { // creates a new window with the last file
   int ww = 500, wh = 800;
   char *fina = new char [200]; strcpy(fina,last_fina);
 
@@ -65,7 +65,7 @@ void spawn(char *last_fina) { // creates a new window with the last file
 
 int main(int argc, char **argv) {
   // if argument given : display it
-  char *fina = (argc > 1) ? argv[1] : "files.c"; 
+  const char *fina = (argc > 1) ? argv[1] : "files.c"; 
   spawn(fina) ;
 }
 
