@@ -2,8 +2,8 @@
 
 #include "font-selector.h"
 
-main(int argc, char **argv) {
+int main(int argc, char **argv) {
   if (argc > 1) sampstr = argv[1];
-  char *mask = (argc > 2) ? argv[2] : "-*-*-*-*-*-*-*-*-*-*-*-*-*-*";
+  char *mask = (argc > 2) ? argv[2] : (char*) "-*-*-*-*-*-*-*-*-*-*-*-*-*-*";
   xfont_select(mask);
 }
