@@ -52,7 +52,7 @@ public:
     }  
     menu_bar *mb = new menu_bar(*this,nx,20,0,0,0,nx/3); // maxw = nx/3
     new template_button <int> (*mb,"new",scan,0);
-    new instance_button <hardc_win> (*mb,"print",&print,this);
+    new instance_button <hardc_win> (*mb,"print",&hardc_win::print,this);
     if (top) {
       new quit_button(*mb);
       main_loop(); 
@@ -125,7 +125,7 @@ void scan(Bool top) {
   new hardc_win(top,xi);
 }
 
-main() {
+int main() {
   scan(True);
 }
 
