@@ -1,7 +1,7 @@
 #include "window.h"
 #include "palette.h"
 
-main() {
+int main() {
   main_window mw("palette",220,60);
   palette_popup *pp = new palette_popup(100);
   palette_popup *pp2 = new palette_popup(100);
