@@ -112,6 +112,8 @@ palette_popup::palette_popup(int ncol, long unsigned *pixels) :
   }
 }
 
+void set_palstr(palette_popup *p, palstr *ps) { p->set_pal(ps); }
+
 // used by the constructors     
 void palette_popup::init_palette(int ncol) {
   ncolors = ncol;
@@ -127,7 +129,7 @@ void palette_popup::init_palette(int ncol) {
   int nbar = sizeof(fbar)/sizeof(palstr); // Elementzahl von fbar
   
   for (i=0; i < nbar; i++)
-    new function_button(*mb,fbar[i].Name, (CB)&set_pal, this, fbar+i);
+    new function_button(*mb,fbar[i].Name,(CB) set_palstr, this, fbar+i);
 
   new palette_display(*this,370,50,x,y,this); y+= 60;
   new unmap_button(*this,"close",100,20,130,y);
