@@ -138,9 +138,8 @@ char *replay_help[] = {
   "'<' goes stepwise back, '<<' resets to zero",0 };
 
 int main(int argc, char *argv[]) {
-
   // if argument is given : use it as filename !
-  char *name = (argc > 1) ? argv[1] : "three-dim";
+  char *name = (argc > 1) ? argv[1] : (char*) "three-dim";
   char *full_name;
   if (strchr(name,'.')) full_name = name; 
   else { // if name contains no "." append ".video" 
