@@ -17,7 +17,7 @@ public:
   }
 };
 
-main() {
+int main() {
   main_window *mw = new main_window("test",600,320);
   new quit_button(*mw,80,20,0,0);
   scrolled_window *scr = new scrolled_window(*mw,300,300,2000,300,0,20);
