@@ -18,34 +18,6 @@ char tree_icon_bits[] = {
    0x00, 0x04, 0x02, 0x20, 0x00, 0x04, 0x01, 0x00, 0x00, 0x88, 0x00, 0x00,
    0x00, 0x50, 0x00, 0x00, 0x00, 0xe0, 0xff, 0x00};
 
-static void rect3d(Window Win, short x, short y, short w, short h, 
-		   GC left_top, GC right_bot) {
-  int i, thickness = 2;  
-  for (i = 0; i < thickness; i++) {
-    short xa = x+i, ya = y+i, xe = x+w-i, ye = y+h-i ; 
-    XPoint xp[5] = { {xa,ye}, {xa,ya}, {xe,ya}, {xe,ye}, {xa,ye}}; // short x,y
-    XDrawLines(display,Win, left_top, xp, 3, CoordModeOrigin);
-    XDrawLines(display,Win, right_bot, xp+2, 3, CoordModeOrigin);
-  }
-}
-
-// calculation of GCs for button colors, outside class definition, 
-// since many buttons can use the same GC 
-// give the brightest colors, the other 2 are set proportional
-void color_GC(unsigned short r, unsigned short g, unsigned short b, GC3 *gc3) {
-  int fg_pix = alloc_color(3*r/4,3*g/4,3*b/4); // inner part
-  int br_pix = alloc_color(r,g,b); // bright rim
-  int lw_pix = alloc_color(r/2,g/2,b/2); // dark rim
-  XGCValues values;
-  
-  values.foreground = fg_pix;
-  gc3->forgr = CreateGC(GCForeground, &values);
-  values.foreground = br_pix;
-  gc3->bright =  CreateGC(GCForeground, &values);
-  values.foreground = lw_pix;
-  gc3->dark =  CreateGC(GCForeground, &values);
-}
-
 // a button with special colors
 
 color_button::color_button(window &parent, char *Name, int w,int h,int x,int y) 
@@ -66,8 +38,8 @@ void color_button::set_GC(struct GC3 *gc3) {
   forgr = gc3->forgr; bright = gc3->bright; dark = gc3->dark;
 }
  
-void color_button::rise() { rect3d(Win,0,0,width-1,height-1, bright, dark); }
-void color_button::drop() { rect3d(Win,0,0,width-1,height-1, dark, bright); }
+void color_button::rise() { frame3d(bright, dark); }
+void color_button::drop() { frame3d(dark, bright); }
 
 int bwmax = 100; // max button width
 static int bhgt = 20; // button height
