@@ -47,11 +47,6 @@ public:
   } 
 };
 
-struct GC3 { GC forgr, bright, dark; }; // 3 GCs for buttons
-
-extern void color_GC(unsigned short r, unsigned short g, unsigned short b, 
-		     GC3 *gc3);
-
 // a button with special colors
 class color_button : public window { 
   GC forgr,bright,dark;
