@@ -84,7 +84,7 @@ void child_print(window *pp) {
 static Bool toggle = False; // state of sb-button : toggle it
 void disable(button *sb) { if (toggle) sb->disable(); else sb->enable(); }
 
-main(int /* argc */, char *argv[]) { 
+int main(int /* argc */, char *argv[]) { 
   main_window *mainw = new main_window(argv[0], 300, 300);  // Main Window
 
   // 1. child : a quit button
