@@ -233,7 +233,7 @@ window::window(window & parent, int w, int h, int x, int y, int bw) {
   height = (h ? h : parent.height) - 2*bw;
   border_width = bw;
   parentw = &parent;
-  hidden = False;  CB_info = False;
+  hidden = CB_info = is_mapped =  False;
   mainw = parent.mainw; // simply pass through
   children = NULL; // own children List = empty
 
@@ -309,6 +309,7 @@ window::~window() {
 }
 
 void window::Map() { 
+  is_mapped = true;
   if (hidden) return; 
   draw_interior();  
   XMapWindow(display, Win);
@@ -325,13 +326,17 @@ void window::Realize() {
   Map(); // the proper sequence (Select, Map) is essential !!
 };
 
-void window::Unmap() { XUnmapWindow(display,Win); };
+void window::Unmap() { is_mapped = false; XUnmapWindow(display,Win); };
+
+int window::map_state() { // returns : IsUnmapped, IsUnviewable, IsViewable 
+  XWindowAttributes watt;
+  XGetWindowAttributes(display,Win,&watt);
+  return watt.map_state;
+}
 
 // to toggle mapping state : if mapped -> Unmap (avv) ; return new map state
 Bool window::toggle_map() {
-  XWindowAttributes watt;
-  XGetWindowAttributes(display,Win,&watt);
-  Bool state = (watt.map_state == IsViewable);
+  Bool state = (map_state() == IsViewable);
   if (state) Unmap(); else Map(); 
   return !state; // it switched
 }
@@ -484,6 +489,10 @@ void window::resize(int w, int h) {
   } 
 } 
 
+void window::frame3d(GC left_top, GC right_bot) {
+  rect3d(Win, 0, 0, width-1, height-1, left_top,right_bot);
+}
+
 // ##################     main_window class    ###########################
 #include "icon.h"
 
@@ -624,6 +633,7 @@ void pixmap_window::clear() {
  
 void pixmap_window::Map() { 
   draw_interior(); 
+  is_mapped = true;
   XCopyArea(display,pix, Win, gc_copy, 0, 0, width, height, 0, 0);
   XMapWindow(display, Win); 
 }
@@ -656,18 +666,28 @@ void pixmap_window::resize(int w, int h) {
   Map();
 }
 
+// calculation of GCs for button colors, outside class definition, 
+// since many buttons can use the same GC 
+// give the brightest colors, the other 2 are set proportional
+void color_GC(unsigned short r, unsigned short g, unsigned short b, GC3 *gc3) {
+  int fg_pix = alloc_color(3*r/4,3*g/4,3*b/4); // inner part
+  int br_pix = alloc_color(r,g,b); // bright rim
+  int lw_pix = alloc_color(r/2,g/2,b/2); // dark rim
+  XGCValues values;
+  
+  values.foreground = fg_pix;
+  gc3->forgr = CreateGC(GCForeground, &values);
+  values.foreground = br_pix;
+  gc3->bright =  CreateGC(GCForeground, &values);
+  values.foreground = lw_pix;
+  gc3->dark =  CreateGC(GCForeground, &values);
+}
+
 // ****************** 3d-shapes ********  
 // draw rectangle in 3d-look with two distinct GCs
 // mode = up3d, flat3d (background pix), down3d
-void rect3d(Window Win, int mode, short x, short y, short w, short h) {
+void rect3d(Window Win, short x, short y, short w, short h, GC left_top, GC right_bot) {
   int i, thickness = 2;  
-  GC left_top,right_bot; // colors for both border parts
-  switch (mode) { 
-  case up3d:   left_top = button_br_gc; right_bot = button_lw_gc; break;
-  case down3d: left_top = button_lw_gc; right_bot = button_br_gc; break;
-  case flat3d: 
-  default: left_top = button_fg_gc; right_bot = button_fg_gc; break;
-  }
   for (i = 0; i < thickness; i++) {
     short xa = x+i, ya = y+i, xe = x+w-i, ye = y+h-i ; 
     XPoint xp[5] = { {xa,ye}, {xa,ya}, {xe,ya}, {xe,ye}, {xa,ye}}; // short x,y
@@ -676,6 +696,21 @@ void rect3d(Window Win, int mode, short x, short y, short w, short h) {
   }
 }
 
+void set_gcs(int mode, GC& left_top, GC& right_bot) { // set GCs for mode
+  switch (mode) { 
+    case up3d:   left_top = button_br_gc; right_bot = button_lw_gc; break;
+    case down3d: left_top = button_lw_gc; right_bot = button_br_gc; break;
+    case flat3d: 
+    default: left_top = button_fg_gc; right_bot = button_fg_gc; break;
+  }
+}
+
+void rect3d(Window Win, int mode, short x, short y, short w, short h) {
+  GC left_top, right_bot; // colors for both border parts
+  set_gcs(mode, left_top, right_bot);
+  rect3d(Win,x,y,w,h,left_top,right_bot);
+}
+
 // analog triangle, points downwards, x,y = left edge
 // mode = up3d, flat3d (background pix), down3d
 void tri3d_s(Window Win, int mode, short x, short y, short w, short h) {
@@ -699,10 +734,25 @@ void tri3d_s(Window Win, int mode, short x, short y, short w, short h) {
 plate::plate(window & parent, int w, int h, int x, int y,int mode3d)  
 : window(parent, w, h, x, y, 0), mode3d(mode3d) { 
   selection_mask |= EnterWindowMask | LeaveWindowMask; 
+  forgr = button_fg_gc; bright = button_br_gc; dark = button_lw_gc; // by default use light-blue
+}
+  
+void plate::set_GC(struct GC3 *gc3) { // set other than the default light-blue
+  forgr = gc3->forgr; bright = gc3->bright; dark = gc3->dark;
+}
+ 
+void plate::frame3d(int mode) {   
+  GC left_top, right_bot; // colors for both border parts
+  switch (mode) { 
+    case up3d:   left_top = bright; right_bot = dark; break;
+    case down3d: left_top = dark; right_bot = bright; break;
+    case flat3d: default: left_top = right_bot = forgr; break;
+  }
+  window::frame3d(left_top, right_bot); 
 }
 
 void plate::redraw() {
-  XFillRectangle(display,Win,button_fg_gc,0,0,width,height); 
+  XFillRectangle(display,Win,forgr,0,0,width,height); 
   default_frame(); // virtual function !
 }
 
@@ -719,7 +769,7 @@ void button::redraw() {
   plate::redraw(); 
   PlaceText(Name);
   if (! enabled) for (int y=3; y < height-3; y +=3) // some lines with button color : dither
-    XDrawLine(display,Win,button_fg_gc,3,y,width-3,y); 
+    XDrawLine(display,Win,forgr,3,y,width-3,y); 
 }
 
 button::~button() {
@@ -986,7 +1036,7 @@ coord_window::coord_window(window & parent, int w, int h, int x, int y,
     w_diff = rxr + rxl; h_diff = ryd + ryu; // the border minus
 }
 
-void coord_window::define_coord(float x1, float y1, float x2, float y2) {
+void coord_window::define_coord(double x1, double y1, double x2, double y2) {
   xl = x1; yd = y1; xr = x2; yu = y2;
   x0 = rxl; y0 = height - ryd; // Window-coordinates of origin
   w_eff = width - w_diff; h_eff = height - h_diff;
@@ -1002,22 +1052,22 @@ void coord_window::resize(int w, int h) {
 }
  
 // compute total window-coordinates from world-values
-int coord_window::x_window(float x) { return x0 + (int)(xf * (x - xl) + .5); }
-int coord_window::y_window(float y) { return y0 - (int)(yf * (y - yd) + .5); }
+int coord_window::x_window(double x) { return x0 + (int)(xf * (x - xl) + .5); }
+int coord_window::y_window(double y) { return y0 - (int)(yf * (y - yd) + .5); }
 
-XPoint coord_window::p_window(float x, float y) { // returns same as XPoint
+XPoint coord_window::p_window(double x, double y) { // returns same as XPoint
   XPoint temp = { x_window(x), y_window(y) };
   return temp;
 }
    
 // back transformation : window coords to world-values
-float coord_window::x_org(int xw) { return (xw - x0)/xf + xl; }
-float coord_window::y_org(int yw) { return (y0 - yw)/yf + yd; }
+double coord_window::x_org(int xw) { return (xw - x0)/xf + xl; }
+double coord_window::y_org(int yw) { return (y0 - yw)/yf + yd; }
 
 void coord_window::draw_coords() { wline(0,yd,0,yu); wline(xl,0,xr,0); }
 
-void coord_window::x_ticks(float dx, int n) { 
-  float xx; 
+void coord_window::x_ticks(double dx, int n) { 
+  double xx; 
   if (xr < xl) dx = -dx; // failsafe
   int y = y_window(0.0);
   for (xx = xl; xx < xr; xx+= dx) { 
@@ -1025,8 +1075,8 @@ void coord_window::x_ticks(float dx, int n) {
     if (n-- == 0) break;
   } 
 }
-void coord_window::y_ticks(float dy, int n) { 
-  int i; float yy = yd;
+void coord_window::y_ticks(double dy, int n) { 
+  int i; double yy = yd;
   if (yu < yd) dy = -dy;
   int x = x_window(0.0);
   for (i = 0; i < n; i++) { 
