@@ -39,11 +39,6 @@ void set_color(unsigned long color); // set color for gc_copy
 int alloc_color(unsigned red, unsigned green, unsigned blue);
 int alloc_named_color(char *colname);
 
-// draws pseudo-3D-borders, mode = up3d, flat3d (background pix), down3d
-void rect3d(Window Win, int mode, short x, short y, short w, short h);
-
-void tri3d_s(Window Win, int mode, short x, short y, short w, short h);
-
 struct point { int x; int y; };
 
 extern Colormap def_cmap;
@@ -82,8 +77,9 @@ protected:
   dhelper *dhlp;     // on EnterCB
   window *parentw;   // only for destructors
   long selection_mask; // default mask for SelectInput
-  Bool hidden;    // if true not realize the window 
+  Bool hidden;      // if true not realize the window 
 public:  
+  Bool is_mapped;   // for fast test if window is mapped
   main_window *mainw; // the main window of this window, direct child of root 
   int width, height;
   int CB_info;   // toggle debug infos on callbacks in this Window
@@ -102,8 +98,9 @@ public:
   virtual void draw_interior() { }   // is called from Map to draw an image 
   virtual void Map(); 
   void Unmap();
+  int map_state(); // returns : IsUnmapped, IsUnviewable, IsViewable 
   Bool toggle_map(); // to toggle mapping state : if mapped -> Unmap (avv)
-  
+
   void set_backing_store();  // set backing_store = WhenMapped
   void set_save_under();     // save covered region when mapped
 
@@ -132,6 +129,11 @@ public:
   void ResetCursor(); // set back to normal
   virtual void redraw() {}
   virtual void resize(int, int);
+  void frame3d(GC left_top, GC right_bot); // 3D-inner-border
+  virtual XImage* GetImage() {  // new 5/2000 : for jpeg savings
+    return XGetImage(display,Win,0,0,width,height,AllPlanes,ZPixmap);
+  }
+  void save_jpeg(char* fina, int q = 60); // q = quality
 protected:  
   virtual void BPress_CB(XButtonEvent) {} 
   virtual void BPress_1_CB(XButtonEvent) {}
@@ -188,7 +190,10 @@ public:
   virtual void Expose_CB(XExposeEvent ev); 
   virtual void draw_interior() {}
   virtual void redraw() { clear(); Map(); }
-  virtual void resize(int,int);
+  virtual void resize(int,int);  
+  virtual XImage* GetImage() {  // new 5/2000 : for jpeg savings
+    return XGetImage(display,pix,0,0,width,height,AllPlanes,ZPixmap);
+  }
 };
 
 // very simple window to place text
@@ -241,14 +246,23 @@ public:
 #define up3d   1 
 #define flat3d 2
 
+// draws 3D-borders, mode = up3d, flat3d (background pix), down3d
+struct GC3 { GC forgr, bright, dark; }; // 3 GCs for buttons
+
+void color_GC(unsigned short r, unsigned short g, unsigned short b, GC3 *gc3);
+void rect3d(Window Win, short x, short y, short w, short h, GC left_top, GC right_bot);
+void rect3d(Window Win, int mode, short x, short y, short w, short h); // use default GS-s
+void tri3d_s(Window Win, int mode, short x, short y, short w, short h);
+
 // a window with pseudo-3d frames
-class plate : public window { 
+class plate : public window, protected GC3 { 
   int mode3d;
 public:
-  plate(window & parent, int w, int h, int x = 0, int y = 0,int mode3d = up3d);
-  virtual void redraw();  
+  plate(window & parent, int w, int h, int x = 0, int y = 0, int mode3d = up3d);
+  virtual void redraw();    
+  void set_GC(struct GC3 *gc3); // set other than the default light-blue
 protected:  
-  void frame3d(int mode) { rect3d(Win, mode, 0, 0, width-1, height-1); }
+  void frame3d(int mode); // set frame for mode
   virtual void default_frame() { frame3d(mode3d); }
 };
 
@@ -600,22 +614,22 @@ protected:
   int x0,y0; // window-coordinates of origin
   int w_eff,h_eff; // effective	width and height of coord-sys
   int w_diff,h_diff,rxl,ryd;
-  float xl,yd, // WC of left, bottom edge (origin, ia: 0,0)
-        xr,yu, // WC of right, top edge (ia: xmax, ymax)
-        xf,yf; // transformation factors
+  double xl,yd, // WC of left, bottom edge (origin, ia: 0,0)
+         xr,yu, // WC of right, top edge (ia: xmax, ymax)
+         xf,yf; // transformation factors
 public:
 
-  void define_coord(float x1, float y1, float x2, float y2);
+  void define_coord(double x1, double y1, double x2, double y2);
   virtual void resize(int, int);
 
   // compute total window-coordinates from world-values
-  int x_window(float x);
-  int y_window(float y);
-  XPoint p_window(float x, float y); // returns same as XPoint
+  int x_window(double x);
+  int y_window(double y);
+  XPoint p_window(double x, double y); // returns same as XPoint
  
   // back transformation : window coords to world-values
-  float x_org(int xw);
-  float y_org(int yw);
+  double x_org(int xw);
+  double y_org(int yw);
 
   // rx : free rand left/right & ry : bottom
   coord_window(window & parent, int w, int h, int x, int y, 
@@ -628,16 +642,16 @@ public:
   
   void draw_coords(); // draw coordinate system 
   // draw x-ticks from xl..xo in dx-steps, max n ticks
-  void x_ticks(float dx, int n = 1000);
-  void y_ticks(float dy, int n = 1000);
+  void x_ticks(double dx, int n = 1000);
+  void y_ticks(double dy, int n = 1000);
 
-  void wline(float x1, float y1, float x2, float y2) {
+  void wline(double x1, double y1, double x2, double y2) {
     line(x_window(x1),y_window(y1),x_window(x2),y_window(y2)); 
   }
   void f_line(f_point p1, f_point p2) { // a line in world coords
     wline(p1.x, p1.y, p2.x, p2.y);
   }
-  void rectangle(float x1, float y1, float x2, float y2) {
+  void rectangle(double x1, double y1, double x2, double y2) {
     wline(x1,y1,x2,y1); wline(x1,y1,x1,y2); 
     wline(x2,y1,x2,y2); wline(x1,y2,x2,y2);
   }
@@ -761,12 +775,12 @@ union fn_union {
 // "xstart" is the starting value of the slider
 
 class scrollbar : public pure_scrollbar {
-  display_window * disp_win;
   pure_scrollbar * ps;
   char str[80];
   void *to_inform; // pointer for 2nd form
   fn_union inffn;
 protected:
+  display_window *disp_win;
   char * format; // the format string for display, like in printf: "Wert = %4x"
   double factor;   // the conversion factor x into pixels = 0..w -> min..max 
 public:
@@ -779,14 +793,12 @@ private:
   float pix_to_val(int pix) { return (pix*factor + min); }
   int val_to_pix(float x) { return (irint((x-min)/factor)); }
 public:
-  void init(window &parent, int w, int h, int x, int y,
-	    float minp, float maxp, float xstart);
-  // 1. construktor
+  void init(window &parent, int w, int h, int x, int y, float minp, float maxp, float xstart);
+  // 1. constructor
   scrollbar(window &parent, void (*inf)(), int w, int h, int x, int y, 
 	    float minp=0, float maxp=0, float xstart = 0,char *format= "%.0f");
-  // 2. construktor
-  scrollbar(window &parent, void (*inf)(void*), void * to_inf,
-	    int w, int h, int x, int y, 
+  // 2. constructor
+  scrollbar(window &parent, void (*inf)(void*), void * to_inf, int w, int h, int x, int y, 
 	    float minp=0, float maxp=0, float xstart=0, char *format= "%.0f");
 
   // explicite setting of slider and display 
@@ -845,7 +857,7 @@ public:
   void reset() { change(min); }
   // called when setting the slider, or indirectly from step_xxx
   void updated() { stp->seek_step(value); }
-  void switch_play() { play_mode = stp->switch_play_mode(&step_fwd, this); }
+  void switch_play() { play_mode = stp->switch_play_mode(&play_scrollbar::step_fwd, this); }
 
   play_scrollbar(window &parent, int w, int x, int y, int n_ticks, stepper *stp,
 		 int minp = 0, int maxp = 0, int xstart = 0);
